@@ -111,8 +111,12 @@ class Worker(QRunnable):
 
     @Slot()  # QtCore.Slot
     def run(self):
-        ingest_msg(self.msg_path, self.collection_ref, self.username, self.password, self.server, self.tenant,
-                   self.callback)
+        try:
+            ingest_msg(self.msg_path, self.collection_ref, self.username, self.password, self.server, self.tenant,
+                       self.callback)
+            self.callback.done()
+        except:
+            self.callback()
 
 
 def ingest_msg(path, collection_ref, username, password, server, tenant, callback):
@@ -222,6 +226,8 @@ class CallBack(QObject):
 
     def __call__(self):
         self.change_value.emit(self.value)
+
+    def done(self):
         self.change_state.emit(PySide2.QtCore.Qt.CheckState.Unchecked)
 
 
@@ -236,9 +242,12 @@ class MyWidget(QMainWindow):
 
     def ingest(self, collection_ref):
         item_model = self.model
-        self.progress = QProgressDialog("Uploading packages...", None, 0, item_model.rowCount() - 1)
-        self.progress.setMinimum(0)
-        self.progress.setMaximum(item_model.rowCount() - 1)
+        emails_to_ingest = 0
+        for i in range(item_model.rowCount()):
+            standard_item = item_model.item(i, 0)
+            if standard_item.checkState() == PySide2.QtCore.Qt.CheckState.Checked:
+                emails_to_ingest = emails_to_ingest + 1
+        self.progress = QProgressDialog("Uploading packages...", None, 0, emails_to_ingest - 1)
         self.progress.setModal(True)
         self.progress.setWindowModality(Qt.WindowModal)
         self.progress.setWindowTitle("Uploads")
@@ -263,7 +272,7 @@ class MyWidget(QMainWindow):
         self.threadpool.setMaxThreadCount(1)
         self.setWindowTitle("Preservica Outlook MSG Importer")
         self.windowModality()
-        if not os.path.isfile("../credentials.properties"):
+        if not os.path.isfile("credentials.properties"):
             dialog = PasswordDialog()
             if dialog.exec_():
                 self.username = dialog.username()
